% Digital PD controller design with pole at origin and zero to be selected.
function [c,zcl]=dpdcon(zeta,wn,g,T)
% g (l) is the uncompensated (compensated) loop gain
% zeta and wn specify the desired closed-loop pole, T= sampling period
% zcl is the closed-loop pole, theta is the angle of the compensator zero at zcl.
% The corresponding gain is "k" and the zero is "a".
wdT = wn*T*sqrt(1-zeta^2);	% Pole angle: T*damped natural frequence
rzcl = exp(-zeta*wn*T)*cos(wdT); 	% Real part of the closed-loop pole.
izcl = exp(-zeta*wn*T)*sin(wdT);	% Imaginary part of the closed-loop pole.
zcl = rzcl + j*izcl;	% Complex closed-loop pole.
% Find the angle of the compensator zero. Include the contribution of the pole at the origin.
thetac=pi - angle(evalfr(g,zcl));
theta = thetac + angle(zcl);
a = rzcl-izcl/tan(theta);	% Calculate the zero location.
c = zpk([-a],[0],1,T);	% Calculate the compensator transfer function.
l=c*g;	% Loop gain.
k = 1/abs( evalfr( l, zcl));	% Calculate the gain.
c=k*c; %Include the correct gain.